@@ -3,13 +3,18 @@
 # code developed in reference to that module and others within unittest2.
 # unittest2 is Copyright (c) 2001-2010 Python Software Foundation; All
 # Rights Reserved. See: http://docs.python.org/license.html
+from __future__ import annotations
 
 import argparse
 import logging
+import typing as t
 import unittest
 
 from nose2 import config, util
 
+if t.TYPE_CHECKING:
+    from nose2.session import Session
+
 log = logging.getLogger(__name__)
 __unittest = True
 
@@ -51,7 +56,6 @@ class PluginMeta(type):
 
 
 class Plugin(metaclass=PluginMeta):
-
     """Base class for nose2 plugins
 
     All nose2 plugins must subclass this class.
@@ -97,8 +101,12 @@ class Plugin(metaclass=PluginMeta):
 
     """
 
-    alwaysOn = False
-    registered = False
+    # annotate instance vars created via PluginMeta
+    session: Session
+    config: config.Config
+
+    alwaysOn: bool = False
+    registered: bool = False
 
     def register(self):
         """Register with appropriate hooks.
@@ -207,7 +215,6 @@ class Plugin(metaclass=PluginMeta):
 
 
 class Hook:
-
     """A plugin hook
 
     Each plugin method in the :class:`nose2.events.PluginInterface` is
@@ -224,9 +231,9 @@ class Hook:
 
     """
 
-    def __init__(self, method):
+    def __init__(self, method) -> None:
         self.method = method
-        self.plugins = []
+        self.plugins: list[Plugin] = []
 
     def __call__(self, event):
         for plugin in self.plugins[:]:
@@ -240,7 +247,6 @@ class Hook:
 
 
 class PluginInterface:
-
     """Definition of plugin interface.
 
     Instances of this class contain the methods that may be called,
@@ -318,10 +324,10 @@ class PluginInterface:
         "handleDir",
         # ... etc?
     )
-    hookClass = Hook
+    hookClass: type[Hook] = Hook
 
-    def __init__(self):
-        self.hooks = {}
+    def __init__(self) -> None:
+        self.hooks: dict[str, list[Hook]] = {}
 
     def addMethod(self, method):
         """Add a method to the available method.
@@ -347,7 +353,6 @@ class PluginInterface:
 
 
 class Event:
-
     """Base class for all events.
 
     .. attribute :: metadata
@@ -366,10 +371,10 @@ class Event:
 
     """
 
-    _attrs = ("handled",)
+    _attrs: t.ClassVar[tuple[str, ...]] = ("handled",)
     version = "0.4"
 
-    def __init__(self, **metadata):
+    def __init__(self, **metadata) -> None:
         self.handled = False
         self.metadata = {}
         self.metadata.update(metadata)
@@ -405,7 +410,6 @@ class Event:
 
 
 class PluginsLoadedEvent(Event):
-
     """Event fired after all plugin classes are loaded.
 
     .. attribute :: pluginsLoaded
@@ -416,13 +420,12 @@ class PluginsLoadedEvent(Event):
 
     _attrs = Event._attrs + ("pluginsLoaded",)
 
-    def __init__(self, pluginsLoaded, **kw):
+    def __init__(self, pluginsLoaded, **kw) -> None:
         self.pluginsLoaded = pluginsLoaded
         super().__init__(**kw)
 
 
 class RunnerCreatedEvent(Event):
-
     """Event fired when test runner is created.
 
     .. attribute :: runner
@@ -434,13 +437,12 @@ class RunnerCreatedEvent(Event):
 
     _attrs = Event._attrs + ("runner",)
 
-    def __init__(self, runner, **kw):
+    def __init__(self, runner, **kw) -> None:
         self.runner = runner
         super().__init__(**kw)
 
 
 class ResultCreatedEvent(Event):
-
     """Event fired when test result handler is created.
 
     .. attribute :: result
@@ -452,13 +454,12 @@ class ResultCreatedEvent(Event):
 
     _attrs = Event._attrs + ("result",)
 
-    def __init__(self, result, **kw):
+    def __init__(self, result, **kw) -> None:
         self.result = result
         super().__init__(**kw)
 
 
 class StartLayerSetupEvent(Event):
-
     """Event fired before running a layer setup.
 
     .. attribute :: layer
@@ -468,13 +469,12 @@ class StartLayerSetupEvent(Event):
 
     _attrs = Event._attrs + ("layer",)
 
-    def __init__(self, layer, **kw):
+    def __init__(self, layer, **kw) -> None:
         self.layer = layer
         super().__init__(**kw)
 
 
 class StopLayerSetupEvent(Event):
-
     """Event fired after running a layer setup.
 
     .. attribute :: layer
@@ -484,13 +484,12 @@ class StopLayerSetupEvent(Event):
 
     _attrs = Event._attrs + ("layer",)
 
-    def __init__(self, layer, **kw):
+    def __init__(self, layer, **kw) -> None:
         self.layer = layer
         super().__init__(**kw)
 
 
 class StartLayerSetupTestEvent(Event):
-
     """Event fired before test cases setups in layers.
 
     .. attribute :: layer
@@ -504,14 +503,13 @@ class StartLayerSetupTestEvent(Event):
 
     _attrs = Event._attrs + ("layer", "test")
 
-    def __init__(self, layer, test, **kw):
+    def __init__(self, layer, test, **kw) -> None:
         self.layer = layer
         self.test = test
         super().__init__(**kw)
 
 
 class StopLayerSetupTestEvent(Event):
-
     """Event fired after test cases setups in layers.
 
     .. attribute :: layer
@@ -525,14 +523,13 @@ class StopLayerSetupTestEvent(Event):
 
     _attrs = Event._attrs + ("layer", "test")
 
-    def __init__(self, layer, test, **kw):
+    def __init__(self, layer, test, **kw) -> None:
         self.layer = layer
         self.test = test
         super().__init__(**kw)
 
 
 class StartLayerTeardownEvent(Event):
-
     """Event fired before running a layer teardown.
 
     .. attribute :: layer
@@ -542,13 +539,12 @@ class StartLayerTeardownEvent(Event):
 
     _attrs = Event._attrs + ("layer",)
 
-    def __init__(self, layer, **kw):
+    def __init__(self, layer, **kw) -> None:
         self.layer = layer
         super().__init__(**kw)
 
 
 class StopLayerTeardownEvent(Event):
-
     """Event fired after running a layer teardown.
 
     .. attribute :: layer
@@ -558,13 +554,12 @@ class StopLayerTeardownEvent(Event):
 
     _attrs = Event._attrs + ("layer",)
 
-    def __init__(self, layer, **kw):
+    def __init__(self, layer, **kw) -> None:
         self.layer = layer
         super().__init__(**kw)
 
 
 class StartLayerTeardownTestEvent(Event):
-
     """Event fired before test cases teardowns in layers.
 
     .. attribute :: layer
@@ -578,14 +573,13 @@ class StartLayerTeardownTestEvent(Event):
 
     _attrs = Event._attrs + ("layer", "test")
 
-    def __init__(self, layer, test, **kw):
+    def __init__(self, layer, test, **kw) -> None:
         self.layer = layer
         self.test = test
         super().__init__(**kw)
 
 
 class StopLayerTeardownTestEvent(Event):
-
     """Event fired after test cases teardowns in layers.
 
     .. attribute :: layer
@@ -599,14 +593,13 @@ class StopLayerTeardownTestEvent(Event):
 
     _attrs = Event._attrs + ("layer", "test")
 
-    def __init__(self, layer, test, **kw):
+    def __init__(self, layer, test, **kw) -> None:
         self.layer = layer
         self.test = test
         super().__init__(**kw)
 
 
 class StartTestRunEvent(Event):
-
     """Event fired when test run is about to start.
 
     Test collection is complete before this event fires, but
@@ -647,7 +640,7 @@ class StartTestRunEvent(Event):
 
     _attrs = Event._attrs + ("runner", "suite", "result", "startTime", "executeTests")
 
-    def __init__(self, runner, suite, result, startTime, executeTests, **kw):
+    def __init__(self, runner, suite, result, startTime, executeTests, **kw) -> None:
         self.suite = suite
         self.runner = runner
         self.result = result
@@ -657,7 +650,6 @@ class StartTestRunEvent(Event):
 
 
 class StopTestRunEvent(Event):
-
     """Event fired when test run has stopped.
 
     .. attribute :: runner
@@ -680,7 +672,7 @@ class StopTestRunEvent(Event):
 
     _attrs = Event._attrs + ("runner", "result", "stopTime", "timeTaken")
 
-    def __init__(self, runner, result, stopTime, timeTaken, **kw):
+    def __init__(self, runner, result, stopTime, timeTaken, **kw) -> None:
         self.runner = runner
         self.result = result
         self.stopTime = stopTime
@@ -689,7 +681,6 @@ class StopTestRunEvent(Event):
 
 
 class StartTestEvent(Event):
-
     """Event fired before a test is executed.
 
     .. attribute :: test
@@ -708,7 +699,7 @@ class StartTestEvent(Event):
 
     _attrs = Event._attrs + ("test", "result", "startTime")
 
-    def __init__(self, test, result, startTime, **kw):
+    def __init__(self, test, result, startTime, **kw) -> None:
         self.test = test
         self.result = result
         self.startTime = startTime
@@ -716,7 +707,6 @@ class StartTestEvent(Event):
 
 
 class StopTestEvent(Event):
-
     """Event fired after a test is executed.
 
     .. attribute :: test
@@ -735,7 +725,7 @@ class StopTestEvent(Event):
 
     _attrs = Event._attrs + ("test", "result", "stopTime")
 
-    def __init__(self, test, result, stopTime, **kw):
+    def __init__(self, test, result, stopTime, **kw) -> None:
         self.test = test
         self.result = result
         self.stopTime = stopTime
@@ -743,7 +733,6 @@ class StopTestEvent(Event):
 
 
 class TestOutcomeEvent(Event):
-
     """Event fired when a test completes.
 
     .. attribute :: test
@@ -817,7 +806,7 @@ class TestOutcomeEvent(Event):
         shortLabel=None,
         longLabel=None,
         **kw,
-    ):
+    ) -> None:
         self.test = test
         self.result = result
         self.outcome = outcome
@@ -830,7 +819,6 @@ class TestOutcomeEvent(Event):
 
 
 class LoadFromModuleEvent(Event):
-
     """Event fired when a test module is loaded.
 
     .. attribute :: loader
@@ -856,17 +844,17 @@ class LoadFromModuleEvent(Event):
 
     _attrs = Event._attrs + ("loader", "module", "extraTests")
 
-    def __init__(self, loader, module, **kw):
+    def __init__(self, loader, module, **kw) -> None:
         self.loader = loader
         self.module = module
-        self.extraTests = []
+        self.extraTests: list[unittest.TestCase] = []
         super().__init__(**kw)
 
 
 class ModuleSuiteEvent(Event):
     _attrs = Event._attrs + ("loader", "module", "suite")
 
-    def __init__(self, loader, module, suite, **kw):
+    def __init__(self, loader, module, suite, **kw) -> None:
         self.loader = loader
         self.module = module
         self.suite = suite
@@ -874,7 +862,6 @@ class ModuleSuiteEvent(Event):
 
 
 class LoadFromTestCaseEvent(Event):
-
     """Event fired when tests are loaded from a test case.
 
     .. attribute :: loader
@@ -900,15 +887,14 @@ class LoadFromTestCaseEvent(Event):
 
     _attrs = Event._attrs + ("loader", "testCase", "extraTests")
 
-    def __init__(self, loader, testCase, **kw):
+    def __init__(self, loader, testCase, **kw) -> None:
         self.loader = loader
         self.testCase = testCase
-        self.extraTests = []
+        self.extraTests: list[unittest.TestCase] = []
         super().__init__(**kw)
 
 
 class LoadFromNamesEvent(Event):
-
     """Event fired to load tests from test names.
 
     .. attribute :: loader
@@ -939,11 +925,11 @@ class LoadFromNamesEvent(Event):
 
     _attrs = Event._attrs + ("loader", "names", "module", "extraTests")
 
-    def __init__(self, loader, names, module, **kw):
+    def __init__(self, loader, names, module, **kw) -> None:
         self.loader = loader
         self.names = names
         self.module = module
-        self.extraTests = []
+        self.extraTests: list[unittest.TestCase] = []
         super().__init__(**kw)
 
     def __str__(self):
@@ -951,7 +937,6 @@ class LoadFromNamesEvent(Event):
 
 
 class LoadFromNameEvent(Event):
-
     """Event fired to load tests from test names.
 
     .. attribute :: loader
@@ -982,16 +967,15 @@ class LoadFromNameEvent(Event):
 
     _attrs = Event._attrs + ("loader", "name", "module", "extraTests")
 
-    def __init__(self, loader, name, module, **kw):
+    def __init__(self, loader, name, module, **kw) -> None:
         self.loader = loader
         self.name = name
         self.module = module
-        self.extraTests = []
+        self.extraTests: list[unittest.TestCase] = []
         super().__init__(**kw)
 
 
 class HandleFileEvent(Event):
-
     """Event fired when a non-test file is examined.
 
     .. note ::
@@ -1035,8 +1019,8 @@ class HandleFileEvent(Event):
 
     _attrs = Event._attrs + ("loader", "name", "path", "pattern", "topLevelDirectory")
 
-    def __init__(self, loader, name, path, pattern, topLevelDirectory, **kw):
-        self.extraTests = []
+    def __init__(self, loader, name, path, pattern, topLevelDirectory, **kw) -> None:
+        self.extraTests: list[unittest.TestCase] = []
         self.path = path
         self.loader = loader
         self.name = name
@@ -1047,7 +1031,6 @@ class HandleFileEvent(Event):
 
 
 class MatchPathEvent(Event):
-
     """Event fired during file matching.
 
     Plugins may return ``False`` and set ``handled`` on this event to prevent
@@ -1070,7 +1053,7 @@ class MatchPathEvent(Event):
 
     _attrs = Event._attrs + ("name", "path", "pattern")
 
-    def __init__(self, name, path, pattern, **kw):
+    def __init__(self, name, path, pattern, **kw) -> None:
         self.path = path
         self.name = name
         self.pattern = pattern
@@ -1078,7 +1061,6 @@ class MatchPathEvent(Event):
 
 
 class GetTestCaseNamesEvent(Event):
-
     """Event fired to find test case names in a test case.
 
     Plugins may return a list of names and set ``handled`` on this
@@ -1126,18 +1108,17 @@ class GetTestCaseNamesEvent(Event):
         "isTestMethod",
     )
 
-    def __init__(self, loader, testCase, isTestMethod, **kw):
+    def __init__(self, loader, testCase, isTestMethod, **kw) -> None:
         self.loader = loader
         self.testCase = testCase
         self.testMethodPrefix = None
-        self.extraNames = []
-        self.excludedNames = []
+        self.extraNames: list[str] = []
+        self.excludedNames: list[str] = []
         self.isTestMethod = isTestMethod
         super().__init__(**kw)
 
 
 class ResultSuccessEvent(Event):
-
     """Event fired at end of test run to determine success.
 
     This event fires at the end of the test run and allows
@@ -1160,14 +1141,13 @@ class ResultSuccessEvent(Event):
 
     _attrs = Event._attrs + ("result", "success")
 
-    def __init__(self, result, success, **kw):
+    def __init__(self, result, success, **kw) -> None:
         self.result = result
         self.success = success
         super().__init__(**kw)
 
 
 class ResultStopEvent(Event):
-
     """Event fired when a test run is told to stop.
 
     Plugins can use this event to prevent other plugins from stopping
@@ -1185,14 +1165,13 @@ class ResultStopEvent(Event):
 
     _attrs = Event._attrs + ("result", "shouldStop")
 
-    def __init__(self, result, shouldStop, **kw):
+    def __init__(self, result, shouldStop, **kw) -> None:
         self.result = result
         self.shouldStop = shouldStop
         super().__init__(**kw)
 
 
 class DescribeTestEvent(Event):
-
     """Event fired to get test description.
 
 
@@ -1213,7 +1192,7 @@ class DescribeTestEvent(Event):
 
     _attrs = Event._attrs + ("test", "description")
 
-    def __init__(self, test, description=None, errorList=False, **kw):
+    def __init__(self, test, description=None, errorList=False, **kw) -> None:
         self.test = test
         self.description = description
         self.errorList = errorList
@@ -1221,7 +1200,6 @@ class DescribeTestEvent(Event):
 
 
 class OutcomeDetailEvent(Event):
-
     """Event fired to acquire additional details about test outcome.
 
     .. attribute :: outcomeEvent
@@ -1239,14 +1217,13 @@ class OutcomeDetailEvent(Event):
 
     _attrs = Event._attrs + ("outcomeEvent", "extraDetail")
 
-    def __init__(self, outcomeEvent, **kw):
+    def __init__(self, outcomeEvent, **kw) -> None:
         self.outcomeEvent = outcomeEvent
-        self.extraDetail = []
+        self.extraDetail: list[str] = []
         super().__init__(**kw)
 
 
 class ReportSummaryEvent(Event):
-
     """Event fired before and after summary report.
 
     .. attribute :: stopTestEvent
@@ -1269,7 +1246,7 @@ class ReportSummaryEvent(Event):
 
     _attrs = Event._attrs + ("stopTestEvent", "stream", "reportCategories")
 
-    def __init__(self, stopTestEvent, stream, reportCategories, **kw):
+    def __init__(self, stopTestEvent, stream, reportCategories, **kw) -> None:
         self.stopTestEvent = stopTestEvent
         self.stream = stream
         self.reportCategories = reportCategories
@@ -1277,7 +1254,6 @@ class ReportSummaryEvent(Event):
 
 
 class ReportTestEvent(Event):
-
     """Event fired to report a test event.
 
     Plugins can respond to this event by producing output for the user.
@@ -1297,14 +1273,13 @@ class ReportTestEvent(Event):
 
     _attrs = Event._attrs + ("testEvent", "stream")
 
-    def __init__(self, testEvent, stream, **kw):
+    def __init__(self, testEvent, stream, **kw) -> None:
         self.testEvent = testEvent
         self.stream = stream
         super().__init__(**kw)
 
 
 class UserInteractionEvent(Event):
-
     """Event fired before and after user interaction.
 
     Plugins that capture stdout or otherwise prevent user interaction
@@ -1316,12 +1291,11 @@ class UserInteractionEvent(Event):
 
     """
 
-    def __init__(self, **kw):
+    def __init__(self, **kw) -> None:
         super().__init__(**kw)
 
 
 class CommandLineArgsEvent(Event):
-
     """Event fired after parsing of command line arguments.
 
     Plugins can respond to this event by configuring themselves or other plugins
@@ -1341,13 +1315,12 @@ class CommandLineArgsEvent(Event):
 
     _attrs = Event._attrs + ("args",)
 
-    def __init__(self, args, **kw):
+    def __init__(self, args, **kw) -> None:
         self.args = args
         super().__init__(**kw)
 
 
 class CreateTestsEvent(Event):
-
     """Event fired before test loading.
 
     Plugins can take over test loading by returning a test suite and setting
@@ -1370,7 +1343,7 @@ class CreateTestsEvent(Event):
 
     _attrs = Event._attrs + ("loader", "testNames", "module")
 
-    def __init__(self, loader, testNames, module, **kw):
+    def __init__(self, loader, testNames, module, **kw) -> None:
         self.loader = loader
         self.testNames = testNames
         self.module = module
@@ -1391,6 +1364,6 @@ class CreatedTestSuiteEvent(Event):
 
     _attrs = Event._attrs + ("suite",)
 
-    def __init__(self, suite, **kw):
+    def __init__(self, suite, **kw) -> None:
         self.suite = suite
         super().__init__(**kw)
