@@ -1,11 +1,15 @@
 """
+.. warning::
+
+    This plugin is now deprecated.
+
 Use this plugin to activate coverage report.
 
-To use this plugin, you need to install ``nose2[coverage_plugin]``. e.g.
+To use this plugin, you need to install ``coverage``. e.g.
 
 ::
 
-    $ pip install nose2[coverage_plugin]>=0.6.5
+    $ pip install nose2 coverage
 
 
 Then, you can enable coverage reporting with :
@@ -28,11 +32,11 @@ specified by `Coverage Config
 However, when doing so you should also be aware of
 `Differences From coverage`_.
 """
-from __future__ import absolute_import, print_function
 
+import io
 import logging
+import sys
 
-from nose2._vendor import six
 from nose2.events import Plugin
 
 log = logging.getLogger(__name__)
@@ -44,18 +48,19 @@ class Coverage(Plugin):
     _mpmode = False
     _subprocess = False
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Get our config and add our command line arguments."""
         # tracking var for any decision which marks the entire run as failed
         self.decided_failure = False
         # buffer for error output data
-        self.error_output_buffer = six.StringIO()
+        self.error_output_buffer = io.StringIO()
 
         self.covSource = self.config.as_list("coverage", []) or ["."]
         self.covReport = self.config.as_list("coverage-report", []) or ["term"]
         self.covConfig = (
             self.config.as_str("coverage-config", "").strip() or ".coveragerc"
         )
+        self.covCombine = self.config.as_bool("coverage-combine", False)
 
         group = self.session.pluginargs
         group.add_argument(
@@ -73,8 +78,10 @@ class Coverage(Plugin):
             metavar="TYPE",
             choices=["term", "term-missing", "annotate", "html", "xml"],
             dest="coverage_report",
-            help="Generate selected reports, available types:"
-            " term, term-missing, annotate, html, xml (multi-allowed)",
+            help=(
+                "Generate selected reports, available types:"
+                " term, term-missing, annotate, html, xml (multi-allowed)"
+            ),
         )
         group.add_argument(
             "--coverage-config",
@@ -124,8 +131,8 @@ class Coverage(Plugin):
             # requesting a better fix in nedbat/coveragepy#34
             self.covController.save()
 
-            if self._mpmode:
-                self.covController.combine(strict=True)
+            if self.covCombine or self._mpmode:
+                self.covController.combine(strict=self._mpmode)
 
             percent_coverage = None
 
@@ -173,6 +180,23 @@ class Coverage(Plugin):
         Now print any buffered error output saved from beforeSummaryReport"""
         print(self.error_output_buffer.getvalue(), file=event.stream)
 
+        # show a warning at the end of output (after any report)
+        #
+        # warnings are not emitted to the user inside of nose2, plus
+        # DeprecationWarning is off by default -- for simplicity, just print
+        # to stderr
+        print(
+            (
+                "**********\n"
+                "WARNING\n"
+                "Support for the nose2 coverage plugin is gradually being removed. "
+                "Use `coverage run nose` instead.\n\n"
+                "For more detail, see https://github.com/nose-devs/nose2/issues/651"
+                "\n**********"
+            ),
+            file=sys.stderr,
+        )
+
     def _start_coverage(self):
         try:
             import coverage
