@@ -79,6 +79,7 @@ produced:
     </testcase>
 
 """
+
 # Based on unittest2/plugins/junitxml.py,
 # which is itself based on the junitxml plugin from py.test
 
@@ -91,7 +92,6 @@ import time
 from xml.etree import ElementTree as ET
 
 from nose2 import events, result, util
-from nose2._vendor import six
 
 __unittest = True
 
@@ -102,7 +102,7 @@ class JUnitXmlReporter(events.Plugin):
     configSection = "junit-xml"
     commandLineSwitch = ("X", "junit-xml", "Generate junit-xml output report")
 
-    def __init__(self):
+    def __init__(self) -> None:
         # Read argument from configuration file, or filled with default
         self.path = os.path.realpath(
             self.config.as_str("path", default="nose2-junit.xml")
@@ -157,7 +157,7 @@ class JUnitXmlReporter(events.Plugin):
         # for generated test cases
         if len(testid_lines) > 1 and self.test_fullname:
             test_args = ":".join(testid_lines[1:])
-            method = "%s (%s)" % (method, test_args)
+            method = f"{method} ({test_args})"
 
         # subtests do not report success
         if event.outcome == result.SUBTEST and event.exc_info is None:
@@ -199,7 +199,7 @@ class JUnitXmlReporter(events.Plugin):
             if msg:
                 skipmsg = "test skipped"
                 if event.reason:
-                    skipmsg = "test skipped: {}".format(event.reason)
+                    skipmsg = f"test skipped: {event.reason}"
                 skipped.set("message", skipmsg)
                 skipped.text = msg
         elif event.outcome == result.FAIL and event.expected:
@@ -226,12 +226,12 @@ class JUnitXmlReporter(events.Plugin):
 
     def _check(self):
         if not os.path.exists(os.path.dirname(self.path)):
-            raise IOError(
+            raise OSError(
                 2, "JUnitXML: Parent folder does not exist for file", self.path
             )
         if self.test_properties is not None:
             if not os.path.exists(self.test_properties_path):
-                raise IOError(
+                raise OSError(
                     2,
                     "JUnitXML: Properties file does not exist",
                     self.test_properties_path,
@@ -281,8 +281,8 @@ class JUnitXmlReporter(events.Plugin):
                 elem.text = i + "  "
             if not elem.tail or not elem.tail.strip():
                 elem.tail = i
-            for elem in elem:
-                self._indent_tree(elem, level + 1)
+            for e in elem:
+                self._indent_tree(e, level + 1)
             if not elem.tail or not elem.tail.strip():
                 elem.tail = i
         else:
@@ -347,18 +347,10 @@ if sys.maxunicode > 0xFFFF:
     ]
 
 ILLEGAL_REGEX_STR = (
-    six.u("[")
-    + six.u("").join(
-        ["%s-%s" % (six.unichr(l), six.unichr(h)) for (l, h) in ILLEGAL_RANGES]
-    )
-    + six.u("]")
+    "[" + "".join([f"{chr(lo)}-{chr(hi)}" for (lo, hi) in ILLEGAL_RANGES]) + "]"
 )
 RESTRICTED_REGEX_STR = (
-    six.u("[")
-    + six.u("").join(
-        ["%s-%s" % (six.unichr(l), six.unichr(h)) for (l, h) in RESTRICTED_RANGES]
-    )
-    + six.u("]")
+    "[" + "".join([f"{chr(lo)}-{chr(hi)}" for (lo, hi) in RESTRICTED_RANGES]) + "]"
 )
 
 _ILLEGAL_REGEX = re.compile(ILLEGAL_REGEX_STR, re.U)
@@ -366,11 +358,11 @@ _RESTRICTED_REGEX = re.compile(RESTRICTED_REGEX_STR, re.U)
 
 
 def string_cleanup(string, keep_restricted=False):
-    if not issubclass(type(string), six.text_type):
-        string = six.text_type(string, encoding="utf-8", errors="replace")
+    if not issubclass(type(string), str):
+        string = str(string, encoding="utf-8", errors="replace")
 
-    string = _ILLEGAL_REGEX.sub(six.u("\uFFFD"), string)
+    string = _ILLEGAL_REGEX.sub("\ufffd", string)
     if not keep_restricted:
-        string = _RESTRICTED_REGEX.sub(six.u("\uFFFD"), string)
+        string = _RESTRICTED_REGEX.sub("\ufffd", string)
 
     return string
