@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 import re
 from collections import OrderedDict
@@ -198,14 +200,14 @@ class LayerReporter(events.Plugin):
     )
     configSection = "layer-reporter"
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.indent = self.config.as_str("indent", "  ")
         self.colors = self.config.as_bool("colors", False)
         self.highlight_words = self.config.as_list(
             "highlight-words", ["A", "having", "should"]
         )
         self.highlight_re = re.compile(r"\b(%s)\b" % "|".join(self.highlight_words))
-        self.layersReported = set()
+        self.layersReported: set[LayerSuite] = set()
 
     def reportStartTest(self, event):
         if self.session.verbosity < 2:
@@ -255,10 +257,10 @@ class LayerReporter(events.Plugin):
 # for debugging
 # def printtree(suite, indent=''):
 #     import unittest
-#     six.print_('%s%s ->' % (indent, getattr(suite, 'layer', 'no layer')))
+#     print('%s%s ->' % (indent, getattr(suite, 'layer', 'no layer')))
 #     for test in suite:
 #         if isinstance(test, unittest.BaseTestSuite):
 #             printtree(test, indent + '  ')
 #         else:
-#             six.print_('%s %s' % (indent, test))
-#     six.print_('%s<- %s' % (indent, getattr(suite, 'layer', 'no layer')))
+#             print('%s %s' % (indent, test))
+#     print('%s<- %s' % (indent, getattr(suite, 'layer', 'no layer')))
