@@ -1,9 +1,13 @@
+from __future__ import annotations
+
 import logging
 import multiprocessing
 import multiprocessing.connection as connection
 import os
+import platform
 import select
 import sys
+import typing as t
 import unittest
 from collections.abc import Sequence
 
@@ -11,11 +15,18 @@ from nose2 import events, loader, result, runner, session, util
 
 log = logging.getLogger(__name__)
 
+if platform.system() == "Windows":
+    MP_CTX: (
+        multiprocessing.context.ForkContext | multiprocessing.context.SpawnContext
+    ) = multiprocessing.get_context("spawn")
+else:
+    MP_CTX = multiprocessing.get_context("fork")
+
 
 class MultiProcess(events.Plugin):
     configSection = "multiprocess"
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.addArgument(
             self.setProcs,
             "N",
@@ -26,7 +37,7 @@ class MultiProcess(events.Plugin):
         self._procs = self.config.as_int("processes", 0)
         self.setAddress(self.config.as_str("bind_address", None))
 
-        self.cases = {}
+        self.cases: dict[str, unittest.TestCase] = {}
 
     @property
     def procs(self):
@@ -176,7 +187,7 @@ class MultiProcess(events.Plugin):
             listener = connection.Listener(address, authkey=authkey)
             return (listener, listener.address + (authkey,))
         else:
-            return multiprocessing.Pipe()
+            return MP_CTX.Pipe()
 
     def _acceptConns(self, parent_conn):
         """
@@ -205,9 +216,7 @@ class MultiProcess(events.Plugin):
         log.debug("Creating %i worker processes", count)
         for _ in range(0, count):
             parent_conn, child_conn = self._prepConns()
-            proc = multiprocessing.Process(
-                target=procserver, args=(session_export, child_conn)
-            )
+            proc = MP_CTX.Process(target=procserver, args=(session_export, child_conn))
             proc.daemon = True
             proc.start()
             parent_conn = self._acceptConns(parent_conn)
@@ -313,7 +322,7 @@ class MultiProcess(events.Plugin):
 
 def procserver(session_export, conn):
     # init logging system
-    rlog = multiprocessing.log_to_stderr()
+    rlog = MP_CTX.log_to_stderr()
     rlog.setLevel(session_export["logLevel"])
 
     # make a real session from the "session" we got
@@ -403,7 +412,6 @@ def gentests(conn):
 
 # custom event classes
 class SubprocessEvent(events.Event):
-
     """Event fired at start and end of subprocess execution.
 
     .. attribute :: loader
@@ -434,7 +442,7 @@ class SubprocessEvent(events.Event):
 
     """
 
-    def __init__(self, loader, result, runner, plugins, connection, **metadata):
+    def __init__(self, loader, result, runner, plugins, connection, **metadata) -> None:
         self.loader = loader
         self.result = result
         self.runner = runner
@@ -445,7 +453,6 @@ class SubprocessEvent(events.Event):
 
 
 class RegisterInSubprocessEvent(events.Event):
-
     """Event fired to notify plugins that multiprocess testing will occur
 
     .. attribute :: pluginClasses
@@ -459,14 +466,14 @@ class RegisterInSubprocessEvent(events.Event):
 
     """
 
-    def __init__(self, **metadata):
-        self.pluginClasses = []
+    def __init__(self, **metadata) -> None:
+        self.pluginClasses: list[type[events.Plugin]] = []
         super().__init__(**metadata)
 
 
 # custom hook system that records calls and events
 class RecordingHook(events.Hook):
-    def __init__(self, method, interface):
+    def __init__(self, method, interface) -> None:
         super().__init__(method)
         self.interface = interface
 
@@ -487,9 +494,9 @@ class RecordingPluginInterface(events.PluginInterface):
         "getTestMethodNames",
     }
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
-        self.events = []
+        self.events: list[tuple[t.Callable[..., t.Any], events.Event]] = []
 
     def log(self, method, event):
         self.events.append((method, event))
