@@ -15,6 +15,7 @@ entries (`plugin` and `always_on`) in the respective
 sections of the configuration file.
 
 """
+
 import cProfile
 import logging
 import pstats
@@ -26,13 +27,12 @@ __unittest = True
 
 
 class Profiler(events.Plugin):
-
     """Profile the test run"""
 
     configSection = "profiler"
     commandLineSwitch = ("P", "profile", "Run tests under profiler")
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.pfile = self.config.as_str("filename", "")
         self.sort = self.config.as_str("sort", "cumulative")
         self.restrict = self.config.as_list("restrict", [])
@@ -45,6 +45,7 @@ class Profiler(events.Plugin):
 
     def beforeSummaryReport(self, event):
         """Output profiling results"""
+
         # write prof output to stream
         class Stream:
             def write(self, *msg):
