@@ -11,7 +11,6 @@ __unittest = True
 
 
 class PluggableTestRunner:
-
     """Test runner that defers most work to plugins.
 
     :param session: Test run session
@@ -25,7 +24,7 @@ class PluggableTestRunner:
 
     resultClass = result.PluggableTestResult
 
-    def __init__(self, session):
+    def __init__(self, session) -> None:
         self.session = session
 
     def run(self, test):
