@@ -1,5 +1,8 @@
 """Common functionality."""
+
+import functools
 import io
+import multiprocessing
 import os.path
 import platform
 import shutil
@@ -15,7 +18,6 @@ SUPPORT = os.path.join(HERE, "functional", "support")
 
 
 class TestCase(unittest.TestCase):
-
     """TestCase extension.
 
     If the class variable ``_RUN_IN_TEMP`` is ``True`` (default: ``False``), tests will
@@ -81,6 +83,19 @@ class FunctionalTestCase(unittest.TestCase):
         if stderr:
             self.assertRegex(util.safe_decode(cmd_stderr), stderr)
 
+    def runInProc(self, working_dir, *args, timeout=10):
+        if not os.path.isabs(working_dir):
+            working_dir = support_file(working_dir)
+
+        proc = subprocess.Popen(
+            [sys.executable, "-m", "nose2"] + list(args),
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            cwd=working_dir,
+        )
+        proc.wait(timeout=timeout)
+        return proc
+
     def runIn(self, testdir, *args, **kw):
         return run_nose2(*args, cwd=testdir, **kw)
 
@@ -89,33 +104,30 @@ class FunctionalTestCase(unittest.TestCase):
 
 
 class _FakeEventBase:
-
     """Baseclass for fake :class:`~nose2.events.Event`s."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.handled = False
         self.version = "0.1"
-        self.metadata = {}
+        self.metadata: dict = {}
 
 
 class FakeHandleFileEvent(_FakeEventBase):
-
     """Fake HandleFileEvent."""
 
-    def __init__(self, name):
+    def __init__(self, name) -> None:
         super().__init__()
 
         self.loader = Stub()  # FIXME
         self.name = name
         self.path = os.path.split(name)[1]
-        self.extraTests = []
+        self.extraTests: list = []
 
 
 class FakeStartTestEvent(_FakeEventBase):
-
     """Fake :class:`~nose2.events.StartTestEvent`."""
 
-    def __init__(self, test):
+    def __init__(self, test) -> None:
         super().__init__()
         self.test = test
         self.result = test.defaultTestResult()
@@ -125,30 +137,27 @@ class FakeStartTestEvent(_FakeEventBase):
 
 
 class FakeLoadFromNameEvent(_FakeEventBase):
-
     """Fake :class:`~nose2.events.LoadFromNameEvent`."""
 
-    def __init__(self, name):
+    def __init__(self, name) -> None:
         super().__init__()
         self.name = name
 
 
 class FakeLoadFromNamesEvent(_FakeEventBase):
-
     """Fake :class:`~nose2.events.LoadFromNamesEvent`."""
 
-    def __init__(self, names):
+    def __init__(self, names) -> None:
         super().__init__()
         self.names = names
 
 
 class FakeStartTestRunEvent(_FakeEventBase):
-
     """Fake :class:`~nose2.events.StartTestRunEvent`"""
 
     def __init__(
         self, runner=None, suite=None, result=None, startTime=None, executeTests=None
-    ):
+    ) -> None:
         super().__init__()
         self.suite = suite
         self.runner = runner
@@ -158,7 +167,6 @@ class FakeStartTestRunEvent(_FakeEventBase):
 
 
 class Stub:
-
     """Stub object for use in tests"""
 
     def __getattr__(self, attr):
@@ -191,7 +199,7 @@ def run_module_as_main(test_module, *args):
 
 
 class NotReallyAProc:
-    def __init__(self, args, cwd=None, **kwargs):
+    def __init__(self, args, cwd=None, **kwargs) -> None:
         self.args = args
         self.chdir = cwd
         self.kwargs = kwargs
@@ -204,13 +212,13 @@ class NotReallyAProc:
         self.cwd = os.getcwd()
         if self.chdir:
             os.chdir(self.chdir)
-        self.stdout = sys.stdout = sys.__stdout__ = io.StringIO()
-        self.stderr = sys.stderr = sys.__stderr__ = io.StringIO()
+        self.stdout = sys.stdout = sys.__stdout__ = io.StringIO()  # type: ignore[misc]
+        self.stderr = sys.stderr = sys.__stderr__ = io.StringIO()  # type: ignore[misc]
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        sys.stdout = sys.__stdout__ = self._stdout
-        sys.stderr = sys.__stderr__ = self._stderr
+        sys.stdout = sys.__stdout__ = self._stdout  # type: ignore[misc]
+        sys.stderr = sys.__stderr__ = self._stderr  # type: ignore[misc]
         if self.chdir:
             os.chdir(self.cwd)
         return False
@@ -238,13 +246,12 @@ class NotReallyAProc:
 
 
 class RedirectStdStreams:
-
     """
     Context manager that replaces the stdin/stdout streams with :class:`StringIO`
     buffers.
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         self.stdout = io.StringIO()
         self.stderr = io.StringIO()
 
@@ -264,9 +271,9 @@ class RedirectStdStreams:
 
 # mock multiprocessing Connection
 class Conn:
-    def __init__(self, items):
+    def __init__(self, items) -> None:
         self.items = items
-        self.sent = []
+        self.sent: list = []
         self.closed = False
 
     def recv(self):
@@ -301,3 +308,22 @@ def _method_name(name="test"):
     """Get an extra method name for Python 3.11"""
     # https://github.com/python/cpython/issues/58473
     return r"\." + name if sys.version_info >= (3, 11) else ""
+
+
+def skip_if_running_in_daemon(testfunc):
+    """
+    mp runs subprocesses with `daemon=True`, so they can't spawn further
+    subproceses. Just skip mp tests in this context.
+
+    This is done at test runtime, not import time.
+    """
+
+    @functools.wraps(testfunc)
+    def wrapper(*args, **kwargs):
+        current_proc = multiprocessing.current_process()
+        if current_proc.daemon:
+            unittest.skip("mp plugin tests cannot run under the mp plugin")
+        else:
+            return testfunc(*args, **kwargs)
+
+    return wrapper
