@@ -1,4 +1,5 @@
 import multiprocessing
+import queue
 import sys
 import threading
 import time
@@ -6,20 +7,26 @@ import unittest
 from multiprocessing import connection
 
 from nose2 import session
-from nose2._vendor import six
 from nose2.plugins import buffer
 from nose2.plugins.loader import discovery, testcases
 from nose2.plugins.mp import MultiProcess, procserver
-from nose2.tests._common import Conn, FunctionalTestCase, _method_name, support_file
+from nose2.tests._common import (
+    Conn,
+    FunctionalTestCase,
+    _method_name,
+    skip_if_running_in_daemon,
+    support_file,
+)
 
 
 class TestMpPlugin(FunctionalTestCase):
     def setUp(self):
-        super(TestMpPlugin, self).setUp()
+        super().setUp()
         self.session = session.Session()
         self.plugin = MultiProcess(session=self.session)
         self.plugin.testRunTimeout = 2
 
+    @skip_if_running_in_daemon
     def test_flatten_without_fixtures(self):
         sys.path.append(support_file("scenario/slow"))
         import test_slow as mod
@@ -32,6 +39,7 @@ class TestMpPlugin(FunctionalTestCase):
         flat = list(self.plugin._flatten(suite))
         self.assertEqual(len(flat), 3)
 
+    @skip_if_running_in_daemon
     def test_flatten_nested_suites(self):
         sys.path.append(support_file("scenario/slow"))
         import test_slow as mod
@@ -47,6 +55,7 @@ class TestMpPlugin(FunctionalTestCase):
         flat = list(self.plugin._flatten(suite2))
         self.assertEqual(len(flat), 3)
 
+    @skip_if_running_in_daemon
     def test_flatten_respects_module_fixtures(self):
         sys.path.append(support_file("scenario/module_fixtures"))
         import test_mf_testcase as mod
@@ -58,6 +67,7 @@ class TestMpPlugin(FunctionalTestCase):
         flat = list(self.plugin._flatten(suite))
         self.assertEqual(flat, ["test_mf_testcase"])
 
+    @skip_if_running_in_daemon
     def test_flatten_respects_class_fixtures(self):
         sys.path.append(support_file("scenario/class_fixtures"))
         import test_cf_testcase as mod
@@ -80,22 +90,24 @@ class TestMpPlugin(FunctionalTestCase):
             ],
         )
 
+    @skip_if_running_in_daemon
     def test_conn_prep(self):
         self.plugin.bind_host = None
-        (parent_conn, child_conn) = self.plugin._prepConns()
-        (parent_pipe, child_pipe) = multiprocessing.Pipe()
+        parent_conn, child_conn = self.plugin._prepConns()
+        parent_pipe, child_pipe = multiprocessing.Pipe()
         self.assertIsInstance(parent_conn, type(parent_pipe))
         self.assertIsInstance(child_conn, type(child_pipe))
 
         self.plugin.bind_host = "127.0.0.1"
         self.plugin.bind_port = 0
-        (parent_conn, child_conn) = self.plugin._prepConns()
+        parent_conn, child_conn = self.plugin._prepConns()
         self.assertIsInstance(parent_conn, connection.Listener)
         self.assertIsInstance(child_conn, tuple)
         self.assertEqual(parent_conn.address, child_conn[:2])
 
+    @skip_if_running_in_daemon
     def test_conn_accept(self):
-        (parent_conn, child_conn) = multiprocessing.Pipe()
+        parent_conn, child_conn = multiprocessing.Pipe()
         self.assertEqual(self.plugin._acceptConns(parent_conn), parent_conn)
 
         listener = connection.Listener(("127.0.0.1", 0))
@@ -117,9 +129,10 @@ class TestMpPlugin(FunctionalTestCase):
 
 class TestProcserver(FunctionalTestCase):
     def setUp(self):
-        super(TestProcserver, self).setUp()
+        super().setUp()
         self.session = session.Session()
 
+    @skip_if_running_in_daemon
     def test_dispatch_tests_receive_events(self):
         ssn = {
             "config": self.session.config,
@@ -161,13 +174,11 @@ class TestProcserver(FunctionalTestCase):
                         {
                             "outcome": "failed",
                             "expected": False,
-                            "metadata": {
-                                "stdout": """\
+                            "metadata": {"stdout": """\
 -------------------- >> begin captured stdout << ---------------------
 Hello stdout
 
---------------------- >> end captured stdout << ----------------------"""
-                            },
+--------------------- >> end captured stdout << ----------------------"""},
                         },
                     ),
                     (
@@ -175,13 +186,11 @@ Hello stdout
                         {
                             "outcome": "failed",
                             "expected": False,
-                            "metadata": {
-                                "stdout": """\
+                            "metadata": {"stdout": """\
 -------------------- >> begin captured stdout << ---------------------
 Hello stdout
 
---------------------- >> end captured stdout << ----------------------"""
-                            },
+--------------------- >> end captured stdout << ----------------------"""},
                         },
                     ),
                     ("stopTest", {}),
@@ -202,6 +211,7 @@ Hello stdout
 
 
 class MPPluginTestRuns(FunctionalTestCase):
+    @skip_if_running_in_daemon
     def test_tests_in_package(self):
         proc = self.runIn(
             "scenario/tests_in_package", "-v", "--plugin=nose2.plugins.mp", "-N=2"
@@ -209,6 +219,7 @@ class MPPluginTestRuns(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 25 tests")
         self.assertEqual(proc.poll(), 1)
 
+    @skip_if_running_in_daemon
     def test_package_in_lib(self):
         proc = self.runIn(
             "scenario/package_in_lib", "-v", "--plugin=nose2.plugins.mp", "-N=2"
@@ -216,6 +227,7 @@ class MPPluginTestRuns(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 3 tests")
         self.assertEqual(proc.poll(), 1)
 
+    @skip_if_running_in_daemon
     def test_module_fixtures(self):
         proc = self.runIn(
             "scenario/module_fixtures", "-v", "--plugin=nose2.plugins.mp", "-N=2"
@@ -223,6 +235,7 @@ class MPPluginTestRuns(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 5 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_class_fixtures(self):
         proc = self.runIn(
             "scenario/class_fixtures", "-v", "--plugin=nose2.plugins.mp", "-N=2"
@@ -230,6 +243,7 @@ class MPPluginTestRuns(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 7 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_large_number_of_tests_stresstest(self):
         proc = self.runIn(
             "scenario/many_tests",
@@ -241,6 +255,7 @@ class MPPluginTestRuns(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 600 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_socket_stresstest(self):
         proc = self.runIn(
             "scenario/many_tests_socket",
@@ -253,6 +268,7 @@ class MPPluginTestRuns(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 600 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_too_many_procs(self):
         # Just need to run the mp plugin with less tests than
         # processes.
@@ -262,11 +278,11 @@ class MPPluginTestRuns(FunctionalTestCase):
             "--plugin=nose2.plugins.mp",
             "-N=2",
         )
-        ret_vals = six.moves.queue.Queue()
+        ret_vals = queue.Queue()
 
         def save_return():
             """
-            Popen.communciate() blocks.  Use a thread-safe queue
+            Popen.communicate() blocks.  Use a thread-safe queue
             to return any exceptions.  Ideally, this completes
             and returns None.
             """
@@ -284,11 +300,12 @@ class MPPluginTestRuns(FunctionalTestCase):
         # little test case.
         try:
             exc = ret_vals.get(True, 60)
-        except six.moves.queue.Empty:
+        except queue.Empty:
             exc = "MP Test timed out"
             proc.kill()
         self.assertIsNone(exc, str(exc))
 
+    @skip_if_running_in_daemon
     def test_with_output_buffer(self):
         proc = self.runIn(
             "scenario/module_fixtures",
@@ -301,6 +318,7 @@ class MPPluginTestRuns(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 5 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_unknown_module(self):
         proc = self.runIn(
             "scenario/module_fixtures",
@@ -320,6 +338,7 @@ class MPPluginTestRuns(FunctionalTestCase):
 
 
 class MPTestClassSupport(FunctionalTestCase):
+    @skip_if_running_in_daemon
     def test_testclass_discover(self):
         proc = self.runIn(
             "scenario/test_classes_mp", "-v", "--plugin=nose2.plugins.mp", "-N=2"
@@ -327,6 +346,7 @@ class MPTestClassSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 13 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_by_module(self):
         proc = self.runIn(
             "scenario/test_classes_mp",
@@ -338,6 +358,7 @@ class MPTestClassSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 8 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_by_class(self):
         proc = self.runIn(
             "scenario/test_classes_mp",
@@ -349,6 +370,7 @@ class MPTestClassSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 8 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_parameters(self):
         proc = self.runIn(
             "scenario/test_classes_mp",
@@ -360,6 +382,7 @@ class MPTestClassSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_generators(self):
         proc = self.runIn(
             "scenario/test_classes_mp",
@@ -373,6 +396,7 @@ class MPTestClassSupport(FunctionalTestCase):
 
 
 class MPClassFixturesSupport(FunctionalTestCase):
+    @skip_if_running_in_daemon
     def test_testcase_class_fixtures(self):
         proc = self.runIn(
             "scenario/class_fixtures", "-v", "test_cf_testcase.Test.test_1"
@@ -381,6 +405,7 @@ class MPClassFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 1 test")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testcase_class_fixtures_mp(self):
         proc = self.runIn(
             "scenario/class_fixtures",
@@ -393,6 +418,7 @@ class MPClassFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testcase_class_fixtures_report_mp(self):
         proc = self.runIn(
             "scenario/class_fixtures",
@@ -417,6 +443,7 @@ class MPClassFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_class_fixtures_and_parameters(self):
         proc = self.runIn(
             "scenario/test_classes_mp", "-v", "test_fixtures_mp.Test.test_params"
@@ -425,6 +452,7 @@ class MPClassFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_class_fixtures_and_parameters_mp(self):
         proc = self.runIn(
             "scenario/test_classes_mp",
@@ -437,6 +465,7 @@ class MPClassFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 5 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_class_fixtures_and_generators(self):
         proc = self.runIn(
             "scenario/test_classes_mp", "-v", "test_fixtures_mp.Test.test_gen"
@@ -445,6 +474,7 @@ class MPClassFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testclass_class_fixtures_and_generators_mp(self):
         proc = self.runIn(
             "scenario/test_classes_mp",
@@ -459,6 +489,7 @@ class MPClassFixturesSupport(FunctionalTestCase):
 
 
 class MPModuleFixturesSupport(FunctionalTestCase):
+    @skip_if_running_in_daemon
     def test_testcase_module_fixtures(self):
         proc = self.runIn(
             "scenario/module_fixtures", "-v", "test_mf_testcase.Test.test_1"
@@ -467,6 +498,7 @@ class MPModuleFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 1 test")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testcase_module_fixtures_mp(self):
         proc = self.runIn(
             "scenario/module_fixtures",
@@ -479,6 +511,7 @@ class MPModuleFixturesSupport(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr="Ran 2 tests")
         self.assertEqual(proc.poll(), 0)
 
+    @skip_if_running_in_daemon
     def test_testcase_module_fixtures_report_mp(self):
         proc = self.runIn(
             "scenario/module_fixtures",
