@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
+import io
 import sys
 
 from nose2 import events, result, session, util
-from nose2._vendor import six
 from nose2.plugins import buffer
 from nose2.tests._common import TestCase
 
@@ -18,29 +18,28 @@ class TestBufferPlugin(TestCase):
         self.plugin.register()
 
         class Test(TestCase):
-
             printed_nonascii_str = util.safe_decode("test 日本").encode("utf-8")
-            printed_unicode = six.u("hello")
+            printed_unicode = "hello"
 
             def test_out(self):
-                six.print_("hello")
+                print("hello")
                 raise {}["oops"]
 
             def test_err(self):
-                six.print_("goodbye", file=sys.stderr)
+                print("goodbye", file=sys.stderr)
 
             def test_mixed_unicode_and_nonascii_str(self):
-                six.print_(self.printed_nonascii_str)
-                six.print_(self.printed_unicode)
-                six.print_(self.printed_nonascii_str, file=sys.stderr)
-                six.print_(self.printed_unicode, file=sys.stderr)
+                print(self.printed_nonascii_str)
+                print(self.printed_unicode)
+                print(self.printed_nonascii_str, file=sys.stderr)
+                print(self.printed_unicode, file=sys.stderr)
                 raise {}["oops"]
 
         self.case = Test
 
         class Watcher(events.Plugin):
-            def __init__(self):
-                self.events = []
+            def __init__(self) -> None:
+                self.events: list[events.TestOutcomeEvent] = []
 
             def testOutcome(self, event):
                 self.events.append(event)
@@ -50,7 +49,7 @@ class TestBufferPlugin(TestCase):
 
     def test_captures_stdout(self):
         out = sys.stdout
-        buf = six.StringIO()
+        buf = io.StringIO()
         sys.stdout = buf
         try:
             test = self.case("test_out")
@@ -63,7 +62,7 @@ class TestBufferPlugin(TestCase):
     def test_captures_stderr_when_configured(self):
         self.plugin.captureStderr = True
         err = sys.stderr
-        buf = six.StringIO()
+        buf = io.StringIO()
         sys.stderr = buf
         try:
             test = self.case("test_err")
@@ -80,22 +79,11 @@ class TestBufferPlugin(TestCase):
         evt = events.OutcomeDetailEvent(self.watcher.events[0])
         self.session.hooks.outcomeDetail(evt)
         extraDetail = "".join(evt.extraDetail)
-        if six.PY2:
-            for string in [
-                util.safe_decode(self.case.printed_nonascii_str),
-                self.case.printed_unicode,
-            ]:
-                assert (
-                    string not in extraDetail
-                ), "Output unexpectedly found in error message"
-            assert "OUTPUT ERROR" in extraDetail
-            assert "UnicodeDecodeError" in extraDetail
-        else:
-            for string in [
-                repr(self.case.printed_nonascii_str),
-                self.case.printed_unicode,
-            ]:
-                assert string in extraDetail, "Output not found in error message"
+        for string in [
+            repr(self.case.printed_nonascii_str),
+            self.case.printed_unicode,
+        ]:
+            assert string in extraDetail, "Output not found in error message"
 
     def test_decorates_outcome_detail(self):
         test = self.case("test_out")
