@@ -10,8 +10,8 @@ class NullHandler(logging.Handler):
         pass
 
 
-class StubPdb(object):
-    def __init__(self):
+class StubPdb:
+    def __init__(self) -> None:
         self.called = False
         self.tb = None
 
